@@ -99,7 +99,7 @@ class res_resistanceValues(IntEnum):
 class pi_spm(object):
     def __init__(self): 
         libpath = "C:\\Program Files (x86)\\Pickering Interfaces Ltd\\Switch Path Manager\\bin\\Pickering.SPM.Client.Native.dll"
-        libpath_pispm = "C:\\Program Files (x86)\\Pickering Interfaces Ltd\\Switch Path Manager\\bin\\piSPM.dll"
+        libpath_pispm = "C:\\Program Files (x86)\\Pickering Interfaces Ltd\\Switch Path Manager\\bin\\piSPM_w32.dll"
         if not os.path.exists(libpath) or '64 bit' in platform.architecture():
             libpath = "C:\\Program Files\\Pickering Interfaces Ltd\\Switch Path Manager\\bin\\Pickering.SPM.Client.Native.dll"
             libpath_pispm = "C:\\Program Files\\Pickering Interfaces Ltd\\Switch Path Manager\\bin\\piSPM_w64.dll"
@@ -560,7 +560,7 @@ class pi_spm(object):
         return err, timeout.value
 
     # #
-    # # Sequencing Functions
+    # #  SPM Startup/Shutdown Sequencing Functions
     # #
     def startSequence(self, disable_notification, project_file,
                        reset, boot_online, show_endmsg, open_close_IDE, reload_prj):
